@@ -1,6 +1,6 @@
 package App::nup;
 
-our $VERSION = "0.9905";
+our $VERSION = "0.9906";
 
 1;
 =encoding utf-8
@@ -21,6 +21,7 @@ nup - N-up multi-column paged output for commands and files
      -e  --exec             execute command mode
          --alias=CMD=OPTS   set command alias
      -V  --parallel         parallel view mode
+     -D  --document         document mode (default: on)
      -F  --fold             fold mode (disable page mode)
      -H  --filename         show filename headers (default: on)
      -G  --grid=#           grid layout (e.g., 2x3)
@@ -40,7 +41,7 @@ nup - N-up multi-column paged output for commands and files
 
 =head1 VERSION
 
-Version 0.9905
+Version 0.9906
 
 =cut
 =head1 DESCRIPTION
@@ -87,21 +88,23 @@ Dry-run mode. Show the command without executing.
 Force command execution mode. Normally the mode is auto-detected,
 but use this option when you want to execute a file as a command.
 
-=item B<--alias>=I<CMD>=I<OPTS>
+=item B<--alias>=I<NAME>=I<CMD> I<OPTS>...
 
-Set command-specific options. When a command matches I<CMD>, the
-specified I<OPTS> are automatically added to the command line.
+Define command alias. When a command matches I<NAME>, it is replaced
+by I<CMD> with specified I<OPTS>.  This can be used to add default
+options or to substitute a different command.
 Multiple C<--alias> options can be specified.
 
 Default aliases:
 
-    bat    --style=plain --color=always
-    rg     --color=always
-    tree   -C
+    bat     bat --style=plain --color=always
+    batcat  batcat --style=plain --color=always
+    rg      rg --color=always
+    tree    tree -C
 
 Example:
 
-    nup --alias='grep=--color=always' grep pattern file
+    nup --alias='grep=ggrep --color=always' grep pattern file
 
 =item B<-V>, B<--parallel>
 
@@ -111,6 +114,12 @@ C<--fold>.  Automatically enabled when multiple files are
 specified.  Single file or stdin input results in single column
 output.
 
+=item B<-D>, B<--document>
+
+Enable document mode for ansicolumn.  This mode is optimized for
+viewing documents with page-based layout.  Enabled by default.
+Use C<--no-document> to disable.
+
 =item B<-F>, B<--fold>
 
 Enable fold mode (disable page mode).  In fold mode, the entire
